pub struct FullQuery {
pub query: String,
pub args: BTreeMap<Arc<str>, TransparentValue>,
}Expand description
A full Trustfall query, with both query and arguments to be used
Fields
query: Stringargs: BTreeMap<Arc<str>, TransparentValue>Implementations
Sourceimpl FullQuery
impl FullQuery
Sourcepub fn from_path(path: &Path) -> Result<FullQuery, Box<dyn Error>>
pub fn from_path(path: &Path) -> Result<FullQuery, Box<dyn Error>>
Extracts a query from a file
Errors
Will return an error variant if
- The path cannot be read for some reason, or
- The file has a supported file extension, but failed to deserialize, or
- The file is of an unsupported file extension, or
- The file is of an unknown file extension