pub fn execute_query(
query: &FullQuery,
manifest_path: ManifestPath,
max_results: Option<usize>,
) -> Vec<BTreeMap<Arc<str>, FieldValue>>Expand description
Executes a Trustfall query at a defined path, using the schema
provided by indicate
Will assume sane defaults for the adapter, such as enabling default features when resolving metadata.
If multiple queries are to be resolved using the same adapter,
execute_query_with_adapter can be used instead.